==> website-php-v.1.0.81.zip: lang/en/wsp-admin/all.inc.php <==
<?php
	define("ADMIN", "Administrator"); 
	define("CONFIG", "Configuration"); 
	define("TEMPLATE", "Template"); 
	define("THEME", "Theme"); 
	
	define("CONFIGURE_SITE", "Configure website");
	define("CONFIGURE_DATABASE", "Configure database");
	define("CONFIGURE_CSS", "Configure styles CSS");
	define("CONFIGURE_SMTP", "Configure send mail");
	
	define("LANGUAGE", "Languages");
	define("ENGLISH", "English");
	define("FRENCH", "French");
	
	define("DISCONNECT", "Disconnect");
	define("CHANGE_PASSWD", "Change password");
	define("CHANGE_PASSWD_CONGRATULATION", "Congratulation, your password has been changed.");
	define("CHANGE_PASSWD_ERROR", "Error, please check your new password not empty or your old password is correct.");
	
	define("NEW_WSP_VERSION", "You can <a href=\"http://www.website-php.com/download.html\" target=\"_blank\">download the last version of Website-PHP</a> (version %s).<br/>");
	define("NEW_BROWSCAP_VERSION", "Browscap.ini is not to date, <a href=\"javascript:void(0);\" onClick=\"%s\">click here to update</a> (version %s).<br/>");
	define("CURRENT_WSP_VERSION", "Current version of Website-PHP: %s");
	define("INSTALL_PHP_SOAP", "Install PHP lib SOAP to be alerted of new version of <a href=\"http://www.website-php.com\" target=\"_blank\">WebSite-PHP</a><br/>");
	
	define("UPDATE_FRAMEWORK", "Update");
	define("UPDATE_FRAMEWORK_WAITING", "Waiting ...");
	define("UPDATE_FRAMEWORK_COMPLETE", "Update complete");
	define("UPDATE_FRAMEWORK_COMPLETE_OK", "Congratulation, %s is to date");
	
	define("PAGE_IN_CONSTRUCTION", "Page in construction, <a href=\"http://www.website-php.com/contact.html\">contact us</a> if you have suggestions or see some errors.");
?>

==> website-php-v.1.0.92.zip: lang/en/wsp-admin/all.inc.php <==
<?php
	define("ADMIN", "Administrator"); 
	define("CONFIG", "Configuration"); 
	define("TEMPLATE", "Template"); 
	define("THEME", "Theme"); 
	
	define("CONFIGURE_SITE", "Configure website");
	define("CONFIGURE_DATABASE", "Configure database");
	define("CONFIGURE_CSS", "Configure styles CSS");
	define("CONFIGURE_SMTP", "Configure send mail");
	define("CONFIGURE_USERS", "Configure users");
	define("CONFIGURE_MODULES", "Configure modules");
	
	define("LANGUAGE", "Languages");
	define("ENGLISH", "English");
	define("FRENCH", "French");
	
	define("DISCONNECT", "Disconnect");
	define("CHANGE_PASSWD", "Change password");
	define("CHANGE_PASSWD_CONGRATULATION", "Congratulation, your password has been changed.");
	define("CHANGE_PASSWD_ERROR", "Error, please check your new password not empty or your old password is correct.");
	
	define("NEW_WSP_VERSION", "You can <a href=\"javascript:void(0);\" onClick=\"%s\">update Website-PHP to the last version</a> (version %s).<br/>");
	define("NEW_BROWSCAP_VERSION", "Browscap.ini is not to date, <a href=\"javascript:void(0);\" onClick=\"%s\">click here to update</a> (version %s).<br/>");
	define("CURRENT_WSP_VERSION", "Current version of Website-PHP: %s");
	define("INSTALL_PHP_SOAP", "Install PHP lib SOAP to be alerted of new version of <a href=\"http://www.website-php.com\" target=\"_blank\">WebSite-PHP</a><br/>");
	
	define("UPDATE_FRAMEWORK", "Update");
	define("UPDATE_FRAMEWORK_WAITING", "Waiting ...");
	define("UPDATE_FRAMEWORK_COMPLETE", "Update complete");
	define("UPDATE_FRAMEWORK_COMPLETE_OK", "Congratulation, %s is to date");
	define("UPDATE_FRAMEWORK_COMPLETE_NOT_OK", "Error, %s is not up to date");
	define("UPDATE_FRAMEWORK_CONFIRM", "Are you sur do you want update %s ?");
	define("UPDATE_FRAMEWORK_WSP_WARNING", "Please note, this update may impact on the current version of your site. We recommend that you save your site (CVS, SVN, ...) and do not do this update in production.");
	define("UPDATE_FRAMEWORK_YES", "Yes");
	define("UPDATE_FRAMEWORK_NO", "No");
	
	define("PAGE_IN_CONSTRUCTION", "Page in construction, <a href=\"http://www.website-php.com/contact.html\">contact us</a> if you have suggestions or see some errors.");
?>
